@@ -20,7 +20,10 @@
 DELIMITER /
 
 
--- KULRICE-7237: KRNS_NTE_T is selected by a field with no indexes - full table scan every time
-create index KRNS_NTE_TI1 on KRNS_NTE_T (RMT_OBJ_ID)
+--
+-- KULRICE-9152: PK for krad_msg_t is too long for MySQL 5.1
+--
+
+ALTER TABLE krad_msg_t MODIFY loc varchar(80) not null
 /
 DELIMITER ;
